# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_recogniseobject.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_recogniseobject.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x1d\x63odemao_recogniseobject.proto\"=\n\x16RecogniseObjectRequest\x12\x12\n\nobjectType\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"Q\n\x17RecogniseObjectResponse\x12\x0f\n\x07objects\x18\x01 \x03(\t\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_RECOGNISEOBJECTREQUEST = _descriptor.Descriptor(
    name='RecogniseObjectRequest',
    full_name='RecogniseObjectRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='objectType', full_name='RecogniseObjectRequest.objectType', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='RecogniseObjectRequest.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=94,
)

_RECOGNISEOBJECTRESPONSE = _descriptor.Descriptor(
    name='RecogniseObjectResponse',
    full_name='RecogniseObjectResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='objects', full_name='RecogniseObjectResponse.objects', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='RecogniseObjectResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='RecogniseObjectResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=96,
    serialized_end=177,
)

DESCRIPTOR.message_types_by_name['RecogniseObjectRequest'] = _RECOGNISEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['RecogniseObjectResponse'] = _RECOGNISEOBJECTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecogniseObjectRequest = _reflection.GeneratedProtocolMessageType('RecogniseObjectRequest', (_message.Message,), {
    'DESCRIPTOR': _RECOGNISEOBJECTREQUEST,
    '__module__': 'codemao_recogniseobject_pb2'
    # @@protoc_insertion_point(class_scope:RecogniseObjectRequest)
})
_sym_db.RegisterMessage(RecogniseObjectRequest)

RecogniseObjectResponse = _reflection.GeneratedProtocolMessageType('RecogniseObjectResponse', (_message.Message,), {
    'DESCRIPTOR': _RECOGNISEOBJECTRESPONSE,
    '__module__': 'codemao_recogniseobject_pb2'
    # @@protoc_insertion_point(class_scope:RecogniseObjectResponse)
})
_sym_db.RegisterMessage(RecogniseObjectResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
