# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_speechrecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='codemao_speechrecognise.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\025com.ubtechinc.codemao',
  serialized_pb=b'\n\x1d\x63odemao_speechrecognise.proto\"<\n\x16SpeechRecogniseRequest\x12\x11\n\ttimeLimit\x18\x01 \x01(\x05\x12\x0f\n\x07\x61srText\x18\x02 \x01(\t\"N\n\x17SpeechRecogniseResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x0c\n\x04text\x18\x03 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)




_SPEECHRECOGNISEREQUEST = _descriptor.Descriptor(
  name='SpeechRecogniseRequest',
  full_name='SpeechRecogniseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeLimit', full_name='SpeechRecogniseRequest.timeLimit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asrText', full_name='SpeechRecogniseRequest.asrText', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=93,
)


_SPEECHRECOGNISERESPONSE = _descriptor.Descriptor(
  name='SpeechRecogniseResponse',
  full_name='SpeechRecogniseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='SpeechRecogniseResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='SpeechRecogniseResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='SpeechRecogniseResponse.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=173,
)

DESCRIPTOR.message_types_by_name['SpeechRecogniseRequest'] = _SPEECHRECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['SpeechRecogniseResponse'] = _SPEECHRECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechRecogniseRequest = _reflection.GeneratedProtocolMessageType('SpeechRecogniseRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNISEREQUEST,
  '__module__' : 'codemao_speechrecognise_pb2'
  # @@protoc_insertion_point(class_scope:SpeechRecogniseRequest)
  })
_sym_db.RegisterMessage(SpeechRecogniseRequest)

SpeechRecogniseResponse = _reflection.GeneratedProtocolMessageType('SpeechRecogniseResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNISERESPONSE,
  '__module__' : 'codemao_speechrecognise_pb2'
  # @@protoc_insertion_point(class_scope:SpeechRecogniseResponse)
  })
_sym_db.RegisterMessage(SpeechRecogniseResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
