# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_AdbSwitch.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_AdbSwitch.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\023com.ubtechinc.alpha',
  serialized_pb=b'\n\x14PyPi_AdbSwitch.proto\" \n\x10\x41\x64\x62SwitchRequest\x12\x0c\n\x04open\x18\x01 \x01(\x08\":\n\x11\x41\x64\x62SwitchResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)




_ADBSWITCHREQUEST = _descriptor.Descriptor(
  name='AdbSwitchRequest',
  full_name='AdbSwitchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='open', full_name='AdbSwitchRequest.open', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=56,
)


_ADBSWITCHRESPONSE = _descriptor.Descriptor(
  name='AdbSwitchResponse',
  full_name='AdbSwitchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='AdbSwitchResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='AdbSwitchResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['AdbSwitchRequest'] = _ADBSWITCHREQUEST
DESCRIPTOR.message_types_by_name['AdbSwitchResponse'] = _ADBSWITCHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdbSwitchRequest = _reflection.GeneratedProtocolMessageType('AdbSwitchRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADBSWITCHREQUEST,
  '__module__' : 'PyPi_AdbSwitch_pb2'
  # @@protoc_insertion_point(class_scope:AdbSwitchRequest)
  })
_sym_db.RegisterMessage(AdbSwitchRequest)

AdbSwitchResponse = _reflection.GeneratedProtocolMessageType('AdbSwitchResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADBSWITCHRESPONSE,
  '__module__' : 'PyPi_AdbSwitch_pb2'
  # @@protoc_insertion_point(class_scope:AdbSwitchResponse)
  })
_sym_db.RegisterMessage(AdbSwitchResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
