# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_setrobotlanguage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='pccodemao_setrobotlanguage.proto',
    package='packet',
    syntax='proto3',
    serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\020SetRobotLanguage',
    serialized_pb=b'\n pccodemao_setrobotlanguage.proto\x12\x06packet\"+\n\x17SetRobotLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"\x8d\x01\n\x18SetRobotLanguageResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x10\n\x08progress\x18\x03 \x01(\x03\x12\r\n\x05total\x18\x04 \x01(\x03\x12)\n\x05state\x18\x05 \x01(\x0e\x32\x1a.packet.SET_LANGUAGE_STATE*9\n\x12SET_LANGUAGE_STATE\x12\x08\n\x04\x46\x41IL\x10\x00\x12\x0c\n\x08\x44OWNLOAD\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x42\x30\n\x1c\x63om.ubtrobot.pccodemao.protoB\x10SetRobotLanguageb\x06proto3'
)

_SET_LANGUAGE_STATE = _descriptor.EnumDescriptor(
    name='SET_LANGUAGE_STATE',
    full_name='packet.SET_LANGUAGE_STATE',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='FAIL', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='DOWNLOAD', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SUCCESS', index=2, number=2,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=233,
    serialized_end=290,
)
_sym_db.RegisterEnumDescriptor(_SET_LANGUAGE_STATE)

SET_LANGUAGE_STATE = enum_type_wrapper.EnumTypeWrapper(_SET_LANGUAGE_STATE)
FAIL = 0
DOWNLOAD = 1
SUCCESS = 2

_SETROBOTLANGUAGEREQUEST = _descriptor.Descriptor(
    name='SetRobotLanguageRequest',
    full_name='packet.SetRobotLanguageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='language', full_name='packet.SetRobotLanguageRequest.language', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=44,
    serialized_end=87,
)

_SETROBOTLANGUAGERESPONSE = _descriptor.Descriptor(
    name='SetRobotLanguageResponse',
    full_name='packet.SetRobotLanguageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='packet.SetRobotLanguageResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='packet.SetRobotLanguageResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='progress', full_name='packet.SetRobotLanguageResponse.progress', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total', full_name='packet.SetRobotLanguageResponse.total', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='state', full_name='packet.SetRobotLanguageResponse.state', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=90,
    serialized_end=231,
)

_SETROBOTLANGUAGERESPONSE.fields_by_name['state'].enum_type = _SET_LANGUAGE_STATE
DESCRIPTOR.message_types_by_name['SetRobotLanguageRequest'] = _SETROBOTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['SetRobotLanguageResponse'] = _SETROBOTLANGUAGERESPONSE
DESCRIPTOR.enum_types_by_name['SET_LANGUAGE_STATE'] = _SET_LANGUAGE_STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetRobotLanguageRequest = _reflection.GeneratedProtocolMessageType('SetRobotLanguageRequest', (_message.Message,), {
    'DESCRIPTOR': _SETROBOTLANGUAGEREQUEST,
    '__module__': 'pccodemao_setrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.SetRobotLanguageRequest)
})
_sym_db.RegisterMessage(SetRobotLanguageRequest)

SetRobotLanguageResponse = _reflection.GeneratedProtocolMessageType('SetRobotLanguageResponse', (_message.Message,), {
    'DESCRIPTOR': _SETROBOTLANGUAGERESPONSE,
    '__module__': 'pccodemao_setrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.SetRobotLanguageResponse)
})
_sym_db.RegisterMessage(SetRobotLanguageResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
