# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_RunWheel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_RunWheel.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x13PyPi_RunWheel.proto\"3\n\x0fRunWheelRequest\x12\x11\n\twheelName\x18\x01 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x02 \x01(\x08\"7\n\x10RunWheelResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_RUNWHEELREQUEST = _descriptor.Descriptor(
  name='RunWheelRequest',
  full_name='RunWheelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheelName', full_name='RunWheelRequest.wheelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='RunWheelRequest.debug', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=74,
)


_RUNWHEELRESPONSE = _descriptor.Descriptor(
  name='RunWheelResponse',
  full_name='RunWheelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='RunWheelResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='RunWheelResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=131,
)

DESCRIPTOR.message_types_by_name['RunWheelRequest'] = _RUNWHEELREQUEST
DESCRIPTOR.message_types_by_name['RunWheelResponse'] = _RUNWHEELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunWheelRequest = _reflection.GeneratedProtocolMessageType('RunWheelRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWHEELREQUEST,
  '__module__' : 'PyPi_RunWheel_pb2'
  # @@protoc_insertion_point(class_scope:RunWheelRequest)
  })
_sym_db.RegisterMessage(RunWheelRequest)

RunWheelResponse = _reflection.GeneratedProtocolMessageType('RunWheelResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWHEELRESPONSE,
  '__module__' : 'PyPi_RunWheel_pb2'
  # @@protoc_insertion_point(class_scope:RunWheelResponse)
  })
_sym_db.RegisterMessage(RunWheelResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
