# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_UploadScript.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_UploadScript.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_UploadScript.proto\"T\n\x0cUploadScript\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\ncreateTime\x18\x03 \x01(\x03\x12\r\n\x05\x65xtra\x18\x04 \x01(\t\";\n\x14UploadScriptResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"@\n\x18ListUploadScriptResponse\x12$\n\ruploadScripts\x18\x01 \x03(\x0b\x32\r.UploadScriptB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_UPLOADSCRIPT = _descriptor.Descriptor(
  name='UploadScript',
  full_name='UploadScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileName', full_name='UploadScript.fileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='UploadScript.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='createTime', full_name='UploadScript.createTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='UploadScript.extra', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=111,
)


_UPLOADSCRIPTRESPONSE = _descriptor.Descriptor(
  name='UploadScriptResponse',
  full_name='UploadScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='UploadScriptResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='UploadScriptResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=172,
)


_LISTUPLOADSCRIPTRESPONSE = _descriptor.Descriptor(
  name='ListUploadScriptResponse',
  full_name='ListUploadScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploadScripts', full_name='ListUploadScriptResponse.uploadScripts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=238,
)

_LISTUPLOADSCRIPTRESPONSE.fields_by_name['uploadScripts'].message_type = _UPLOADSCRIPT
DESCRIPTOR.message_types_by_name['UploadScript'] = _UPLOADSCRIPT
DESCRIPTOR.message_types_by_name['UploadScriptResponse'] = _UPLOADSCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['ListUploadScriptResponse'] = _LISTUPLOADSCRIPTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadScript = _reflection.GeneratedProtocolMessageType('UploadScript', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRIPT,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:UploadScript)
  })
_sym_db.RegisterMessage(UploadScript)

UploadScriptResponse = _reflection.GeneratedProtocolMessageType('UploadScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRIPTRESPONSE,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:UploadScriptResponse)
  })
_sym_db.RegisterMessage(UploadScriptResponse)

ListUploadScriptResponse = _reflection.GeneratedProtocolMessageType('ListUploadScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUPLOADSCRIPTRESPONSE,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:ListUploadScriptResponse)
  })
_sym_db.RegisterMessage(ListUploadScriptResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
