# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_getrobotlanguage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='pccodemao_getrobotlanguage.proto',
    package='packet',
    syntax='proto3',
    serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\020GetRobotLanguage',
    serialized_pb=b'\n pccodemao_getrobotlanguage.proto\x12\x06packet\"\x19\n\x17GetRobotLanguageRequest\"S\n\x18GetRobotLanguageResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x10\n\x08language\x18\x03 \x01(\tB0\n\x1c\x63om.ubtrobot.pccodemao.protoB\x10GetRobotLanguageb\x06proto3'
)

_GETROBOTLANGUAGEREQUEST = _descriptor.Descriptor(
    name='GetRobotLanguageRequest',
    full_name='packet.GetRobotLanguageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=44,
    serialized_end=69,
)

_GETROBOTLANGUAGERESPONSE = _descriptor.Descriptor(
    name='GetRobotLanguageResponse',
    full_name='packet.GetRobotLanguageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='packet.GetRobotLanguageResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='packet.GetRobotLanguageResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='language', full_name='packet.GetRobotLanguageResponse.language', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=71,
    serialized_end=154,
)

DESCRIPTOR.message_types_by_name['GetRobotLanguageRequest'] = _GETROBOTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['GetRobotLanguageResponse'] = _GETROBOTLANGUAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRobotLanguageRequest = _reflection.GeneratedProtocolMessageType('GetRobotLanguageRequest', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTLANGUAGEREQUEST,
    '__module__': 'pccodemao_getrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.GetRobotLanguageRequest)
})
_sym_db.RegisterMessage(GetRobotLanguageRequest)

GetRobotLanguageResponse = _reflection.GeneratedProtocolMessageType('GetRobotLanguageResponse', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTLANGUAGERESPONSE,
    '__module__': 'pccodemao_getrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.GetRobotLanguageResponse)
})
_sym_db.RegisterMessage(GetRobotLanguageResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
